@@ -30,6 +30,9 @@ def parse_input_args():
     root_parser.add_argument(
         '-d', '--debug', dest='debug', action='store_true',
         help='Debug mode for Flask', default=None)
+    root_parser.add_argument(
+        '--force', dest='force', action='store_true',
+        help='Force creation new resources if exist')
     root_parser.add_argument(
         '--root-dir', dest='root_dir', default='.',
         help='Projects root directory')
@@ -61,6 +64,9 @@ def parse_input_args():
     root_parser.add_argument(
         '--ml-backend-name', dest='ml_backend_name',
         help='Machine learning backend name')
+    root_parser.add_argument(
+        '-p', '--port', dest='port', default=8200, type=int,
+        help='Server port')
 
     parser = argparse.ArgumentParser(description='Label studio')
 
@@ -80,9 +86,6 @@ def parse_input_args():
     parser_start.add_argument(
         'project_name',
         help='Path to directory where project state has been initialized')
-    parser_start.add_argument(
-        '-p', '--port', dest='port', default=8200, type=int,
-        help='Server port')
     parser_start.add_argument(
         '--init', dest='init', action='store_true',
         help='Initialize if project is not initialized yet')
@@ -91,13 +94,8 @@ def parse_input_args():
 
     parser_start_ms = subparsers.add_parser(
         'start-multi-session', help='Start Label Studio server', parents=[root_parser])
-    parser_start_ms.add_argument(
-        '-p', '--port', dest='port', default=8200, type=int,
-        help='Server port')
 
     args = parser.parse_args()
-    if args.config_path is not None:
-        raise RuntimeError('"--config" option is deprecated. Use command line arguments')
     if args.output_dir is not None:
         raise RuntimeError('"--output-dir" option is deprecated and has no effect.\n'
                            'All output results are saved to project_name/completions directory')
