@@ -2,6 +2,8 @@ import os
 import pkg_resources
 import shutil
 import glob
+import io
+import json
 
 from contextlib import contextmanager
 from tempfile import mkstemp, mkdtemp
@@ -84,3 +86,22 @@ def get_data_dir():
 def delete_dir_content(dirpath):
     for f in glob.glob(dirpath + '/*'):
         os.remove(f)
+
+
+def remove_file_or_dir(path):
+    if os.path.isfile(path):
+        os.remove(path)
+    elif os.path.isdir(path):
+        shutil.rmtree(path)
+
+
+def iter_files(root_dir, ext):
+    for root, _, files in os.walk(root_dir):
+        for f in files:
+            if f.lower().endswith(ext):
+                yield os.path.join(root, f)
+
+
+def json_load(file):
+    with io.open(file) as f:
+        return json.load(f)
